==> jc-1.4.0.tar.gz: java/security/BasicPermission.h <==
// public abstract class java.security.BasicPermission

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class d5158e4c9a3bab21 java_security_BasicPermission
// @dep_class 2377c76e79058a72 java_security_Permission

// header file dependencies
// @dep_header java_security_Permission

#include "java/security/Permission.h"

#ifndef _JC_java_security_BasicPermission_H_
#define _JC_java_security_BasicPermission_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_java_security_Permission$object;
struct _jc_java_security_PermissionCollection$object;

// Typedefs
typedef struct _jc_java_security_BasicPermission$sub_refs	_jc_java_security_BasicPermission$sub_refs;
typedef struct _jc_java_security_BasicPermission$sub_nonrefs	_jc_java_security_BasicPermission$sub_nonrefs;
typedef struct _jc_java_security_BasicPermission$refs	_jc_java_security_BasicPermission$refs;
typedef struct _jc_java_security_BasicPermission$nonrefs	_jc_java_security_BasicPermission$nonrefs;
typedef struct _jc_java_security_BasicPermission$object	_jc_java_security_BasicPermission$object;

typedef struct _jc_java_security_BasicPermission$fields_struct	_jc_java_security_BasicPermission$fields_struct;
typedef const struct _jc_java_security_BasicPermission$vmethods	_jc_java_security_BasicPermission$vmethods;
typedef const struct _jc_java_security_BasicPermission$vtable	_jc_java_security_BasicPermission$vtable;
typedef const struct _jc_java_security_BasicPermission$vtype	_jc_java_security_BasicPermission$vtype;

// Class fields structure
struct _jc_java_security_BasicPermission$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_security_BasicPermission$fields_struct _jc_java_security_BasicPermission$class_fields;

// Constructors
extern void _jc_java_security_BasicPermission$method$_init$c31b894660454d13(_jc_env *, struct _jc_java_security_BasicPermission$object *, struct _jc_java_lang_String$object *);
extern void _jc_java_security_BasicPermission$method$_init$a34354cd9552963f(_jc_env *, struct _jc_java_security_BasicPermission$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *);

// Virtual methods
extern jboolean _jc_java_security_BasicPermission$method$equals$8a15e0625571c581(_jc_env *, struct _jc_java_security_BasicPermission$object *, struct _jc_java_lang_Object$object *);
extern struct _jc_java_lang_String$object *_jc_java_security_BasicPermission$method$getActions$a96d1cd349ac27ec(_jc_env *, struct _jc_java_security_BasicPermission$object *);
extern jint _jc_java_security_BasicPermission$method$hashCode$53152098849316df(_jc_env *, struct _jc_java_security_BasicPermission$object *);
extern jboolean _jc_java_security_BasicPermission$method$implies$cbacf9d54b2bb917(_jc_env *, struct _jc_java_security_BasicPermission$object *, struct _jc_java_security_Permission$object *);
extern struct _jc_java_security_PermissionCollection$object *_jc_java_security_BasicPermission$method$newPermissionCollection$89e97753129a52a5(_jc_env *, struct _jc_java_security_BasicPermission$object *);

// Virtual method descriptors
extern _jc_method _jc_java_security_BasicPermission$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_java_security_BasicPermission$method_info$getActions$a96d1cd349ac27ec;
extern _jc_method _jc_java_security_BasicPermission$method_info$hashCode$53152098849316df;
extern _jc_method _jc_java_security_BasicPermission$method_info$implies$cbacf9d54b2bb917;
extern _jc_method _jc_java_security_BasicPermission$method_info$newPermissionCollection$89e97753129a52a5;

// Virtual methods structure
struct _jc_java_security_BasicPermission$vmethods {
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_java_security_BasicPermission$object *, struct _jc_java_lang_Object$object *);
	struct _jc_java_lang_String$object	*(*getActions$a96d1cd349ac27ec)(_jc_env *, struct _jc_java_security_BasicPermission$object *);
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_java_security_BasicPermission$object *);
	jboolean	(*implies$cbacf9d54b2bb917)(_jc_env *, struct _jc_java_security_BasicPermission$object *, struct _jc_java_security_Permission$object *);
	struct _jc_java_security_PermissionCollection$object	*(*newPermissionCollection$89e97753129a52a5)(_jc_env *, struct _jc_java_security_BasicPermission$object *);
};

// Vtable
struct _jc_java_security_BasicPermission$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_security_Permission$vmethods	java_security_Permission;
	_jc_java_security_BasicPermission$vmethods	java_security_BasicPermission;
};

// Vtype
struct _jc_java_security_BasicPermission$vtype {
	_jc_type			type;
	_jc_java_security_BasicPermission$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_security_BasicPermission$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_security_BasicPermission$refs {
    _jc_java_security_BasicPermission$sub_refs	java_security_BasicPermission;
    _jc_java_security_Permission$sub_refs	java_security_Permission;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_security_BasicPermission$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_security_BasicPermission$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_security_Permission$sub_nonrefs	java_security_Permission;
    _jc_java_security_BasicPermission$sub_nonrefs	java_security_BasicPermission;
};

// Object instance structure
struct _jc_java_security_BasicPermission$object {
	_jc_java_security_BasicPermission$refs	refs[0];
	_jc_word		lockword;
	_jc_java_security_BasicPermission$vtype	*vtype;
	_jc_java_security_BasicPermission$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_security_BasicPermission$vtype _jc_java_security_BasicPermission$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_security_BasicPermission, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_security_BasicPermission$class_object;

#endif	/* _JC_java_security_BasicPermission_H_ */

==> jc-1.4.6.tar.gz: java/security/BasicPermission.h <==
// public abstract class java.security.BasicPermission

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class d5158e4c9a3bab21 java_security_BasicPermission
// @dep_class 2377c76e79058a72 java_security_Permission

// header file dependencies
// @dep_header java_security_Permission

#include "java/security/Permission.h"

#ifndef _JC_java_security_BasicPermission_H_
#define _JC_java_security_BasicPermission_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_java_security_Permission$object;
struct _jc_java_security_PermissionCollection$object;

// Typedefs
typedef struct _jc_java_security_BasicPermission$sub_refs	_jc_java_security_BasicPermission$sub_refs;
typedef struct _jc_java_security_BasicPermission$sub_nonrefs	_jc_java_security_BasicPermission$sub_nonrefs;
typedef struct _jc_java_security_BasicPermission$refs	_jc_java_security_BasicPermission$refs;
typedef struct _jc_java_security_BasicPermission$nonrefs	_jc_java_security_BasicPermission$nonrefs;
typedef struct _jc_java_security_BasicPermission$object	_jc_java_security_BasicPermission$object;

typedef struct _jc_java_security_BasicPermission$fields_struct	_jc_java_security_BasicPermission$fields_struct;
typedef const struct _jc_java_security_BasicPermission$vmethods	_jc_java_security_BasicPermission$vmethods;
typedef const struct _jc_java_security_BasicPermission$vtable	_jc_java_security_BasicPermission$vtable;
typedef const struct _jc_java_security_BasicPermission$vtype	_jc_java_security_BasicPermission$vtype;

// Class fields structure
struct _jc_java_security_BasicPermission$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_security_BasicPermission$fields_struct _jc_java_security_BasicPermission$class_fields;

// Constructors
extern void _jc_java_security_BasicPermission$method$_init$c31b894660454d13(_jc_env *, struct _jc_java_security_BasicPermission$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern void _jc_java_security_BasicPermission$method$_init$a34354cd9552963f(_jc_env *, struct _jc_java_security_BasicPermission$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_java_security_BasicPermission$method$equals$8a15e0625571c581(_jc_env *, struct _jc_java_security_BasicPermission$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_java_security_BasicPermission$method$getActions$a96d1cd349ac27ec(_jc_env *, struct _jc_java_security_BasicPermission$object *) _JC_JCNI_ATTR;
extern jint _jc_java_security_BasicPermission$method$hashCode$53152098849316df(_jc_env *, struct _jc_java_security_BasicPermission$object *) _JC_JCNI_ATTR;
extern jboolean _jc_java_security_BasicPermission$method$implies$cbacf9d54b2bb917(_jc_env *, struct _jc_java_security_BasicPermission$object *, struct _jc_java_security_Permission$object *) _JC_JCNI_ATTR;
extern struct _jc_java_security_PermissionCollection$object *_jc_java_security_BasicPermission$method$newPermissionCollection$89e97753129a52a5(_jc_env *, struct _jc_java_security_BasicPermission$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_security_BasicPermission$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_java_security_BasicPermission$method_info$getActions$a96d1cd349ac27ec;
extern _jc_method _jc_java_security_BasicPermission$method_info$hashCode$53152098849316df;
extern _jc_method _jc_java_security_BasicPermission$method_info$implies$cbacf9d54b2bb917;
extern _jc_method _jc_java_security_BasicPermission$method_info$newPermissionCollection$89e97753129a52a5;

// Virtual methods structure
struct _jc_java_security_BasicPermission$vmethods {
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_java_security_BasicPermission$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getActions$a96d1cd349ac27ec)(_jc_env *, struct _jc_java_security_BasicPermission$object *) _JC_JCNI_ATTR;
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_java_security_BasicPermission$object *) _JC_JCNI_ATTR;
	jboolean	(*implies$cbacf9d54b2bb917)(_jc_env *, struct _jc_java_security_BasicPermission$object *, struct _jc_java_security_Permission$object *) _JC_JCNI_ATTR;
	struct _jc_java_security_PermissionCollection$object	*(*newPermissionCollection$89e97753129a52a5)(_jc_env *, struct _jc_java_security_BasicPermission$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_security_BasicPermission$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_security_Permission$vmethods	java_security_Permission;
	_jc_java_security_BasicPermission$vmethods	java_security_BasicPermission;
};

// Vtype
struct _jc_java_security_BasicPermission$vtype {
	_jc_type			type;
	_jc_java_security_BasicPermission$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_security_BasicPermission$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_security_BasicPermission$refs {
    _jc_java_security_BasicPermission$sub_refs	java_security_BasicPermission;
    _jc_java_security_Permission$sub_refs	java_security_Permission;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_security_BasicPermission$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_security_BasicPermission$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_security_Permission$sub_nonrefs	java_security_Permission;
    _jc_java_security_BasicPermission$sub_nonrefs	java_security_BasicPermission;
};

// Object instance structure
struct _jc_java_security_BasicPermission$object {
	_jc_java_security_BasicPermission$refs	refs[0];
	_jc_word		lockword;
	_jc_java_security_BasicPermission$vtype	*vtype;
	_jc_java_security_BasicPermission$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_security_BasicPermission$vtype _jc_java_security_BasicPermission$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_security_BasicPermission, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_security_BasicPermission$class_object;

#endif	/* _JC_java_security_BasicPermission_H_ */
